Name
That doesn't look like a valid volume name.
Your volume name is too long.
Size (GB)
You did not enter a valid number.
You did not enter a positive number.
Volume Type {$ vtype.name $} Availability Zone {$ az.name $} {$ 'Show More Properties' | translate $} Description
Please do not input invalid characters!
Please input the description less than 255 characters.
multiattach readonly Create from source {$ source.name $} Backup ID {$ backup.name $} Image {$ image.name $} Snapshot {$ snapshot.name $} Source Volume {$ volume.name $} Metadata
Key Value
Scheduler Hints
Key Value